# tileMatrixSet json documents

TileMatrixSet from http://schemas.opengis.net/tms/1.0/json/examples/

`NZTM2000` and `LINZAntarticaMapTilegrid` are from GDAL https://github.com/OSGeo/gdal/pull/2505/files#diff-33251b8c7db3e78835102ded8d11d851
